@@ -1,45 +1,76 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
+build_time_vars = {'ABIFLAGS': '',
+ 'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': './Parser/asdl_c.py',
+ 'ASDLGEN': '@echo python: not-found! cannot run ./Parser/asdl_c.py # '
+            './Parser/asdl_c.py',
  'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
  'AST_ASDL': './Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
  'AST_H_DIR': 'Include',
- 'ATHEOS_THREADS': 0,
- 'BASECFLAGS': '-fno-strict-aliasing',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
+ 'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BEOS_THREADS': 0,
  'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python2.7',
- 'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared -L/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'BINLIBDEST': '/usr/pkg/lib/python3.5',
+ 'BLDLIBRARY': '-L. -lpython3.5',
+ 'BLDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib '
+              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'CC': 'gcc',
+ 'BUILD_GNU_TYPE': 'arm--netbsdelf-eabi',
+ 'BYTESTR_DEPS': '\\',
+ 'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2  -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
+           '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
- 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-threads' '--enable-shared' 'OPT=-O2  -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include' '--with-system-ffi' '--with-dbmliborder=ndbm:bdb' '--prefix=/usr/pkg' '--build=arm--netbsdelf-eabi' '--host=arm--netbsdelf-eabi' '--mandir=/usr/pkg/man' 'build_alias=arm--netbsdelf-eabi' 'host_alias=arm--netbsdelf-eabi' 'CC=gcc' 'CFLAGS=-O2 -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' 'PKG_CONFIG_PATH=' 'PKG_CONFIG_LIBDIR=/mnt/earm/pkgsrc/lang/python27/work.earm/.buildlink/lib/pkgconfig:/mnt/earm/pkgsrc/lang/python27/work.earm/.buildlink/share/pkgconfig'",
+ 'CFLAGS_NODIST': '',
+ 'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
+                'Makefile.pre.in',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
+ 'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+                      '-Wl,-R/usr/pkg/lib',
+ 'CONFIG_ARGS': "'--with-threads' '--enable-shared' 'OPT=-O2 -I/usr/include "
+                "-I/usr/pkg/include' '--with-system-ffi' '--without-pymalloc' "
+                "'--without-ensurepip' '--prefix=/usr/pkg' "
+                "'--build=arm--netbsdelf-eabi' '--host=arm--netbsdelf-eabi' "
+                "'--mandir=/usr/pkg/man' 'build_alias=arm--netbsdelf-eabi' "
+                "'host_alias=arm--netbsdelf-eabi' 'CC=gcc' 'CFLAGS=-O2 "
+                "-I/usr/include -I/usr/pkg/include' 'LDFLAGS=-L/usr/lib "
+                "-Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'PKG_CONFIG=' "
+                "'PKG_CONFIG_PATH=' "
+                "'PKG_CONFIG_LIBDIR=/mnt/earm/pkgsrc/lang/python35/work.earm/.buildlink/lib/pkgconfig:/mnt/earm/pkgsrc/lang/python35/work.earm/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python2.7',
- 'COREPYTHONPATH': ':plat-netbsd7:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include',
- 'CXX': 'c++',
- 'C_THREADS': 0,
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python2.7 /usr/pkg/lib/python2.7/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python2.7',
+ 'CONFINCLUDEPY': '/usr/pkg/include/python3.5',
+ 'COREPYTHONPATH': ':plat-netbsd7',
+ 'COVERAGE_INFO': '/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1/lcov-report',
+ 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
+                            'report"',
+ 'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include '
+             '-I/usr/include -I/usr/pkg/include',
+ 'CXX': 'c++ -pthread',
+ 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.5 '
+             '/usr/pkg/lib/python3.5/lib-dynload',
+ 'DESTLIB': '/usr/pkg/lib/python3.5',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python2.7/lib-dynload',
+ 'DESTSHARED': '/usr/pkg/lib/python3.5/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Demo Ext-dummy',
- 'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
+         'Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DISTDIRS': 'Include Lib Misc Ext-dummy',
+ 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h '
+              'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -51,30 +82,31 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'EXE': '',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
- 'EXTRAPLATDIR': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
+ 'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
- 'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
  'GRAMMAR_INPUT': './Grammar/Grammar',
+ 'HAVE_ACCEPT4': 0,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
+ 'HAVE_ALIGNED_REQUIRED': 0,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
  'HAVE_ASM_TYPES_H': 0,
  'HAVE_ATANH': 1,
- 'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 1,
+ 'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
@@ -82,11 +114,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
+ 'HAVE_BUILTIN_ATOMIC': 1,
  'HAVE_C99_BOOL': 1,
  'HAVE_CHFLAGS': 1,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_CLOCK_GETRES': 1,
+ 'HAVE_CLOCK_GETTIME': 1,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -105,22 +140,32 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DEV_PTC': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
+ 'HAVE_DIRENT_D_TYPE': 1,
  'HAVE_DIRENT_H': 1,
+ 'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
+ 'HAVE_DUP3': 1,
  'HAVE_DYNAMIC_LOADING': 1,
+ 'HAVE_ENDIAN_H': 0,
  'HAVE_EPOLL': 0,
+ 'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPM1': 1,
+ 'HAVE_FACCESSAT': 1,
  'HAVE_FCHDIR': 1,
  'HAVE_FCHMOD': 1,
+ 'HAVE_FCHMODAT': 1,
  'HAVE_FCHOWN': 1,
+ 'HAVE_FCHOWNAT': 1,
  'HAVE_FCNTL_H': 1,
  'HAVE_FDATASYNC': 1,
+ 'HAVE_FDOPENDIR': 1,
+ 'HAVE_FEXECVE': 0,
  'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
@@ -128,19 +173,26 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
  'HAVE_FSEEKO': 1,
+ 'HAVE_FSTATAT': 1,
  'HAVE_FSTATVFS': 1,
  'HAVE_FSYNC': 1,
  'HAVE_FTELL64': 0,
  'HAVE_FTELLO': 1,
  'HAVE_FTIME': 0,
  'HAVE_FTRUNCATE': 1,
+ 'HAVE_FUTIMENS': 1,
+ 'HAVE_FUTIMES': 1,
+ 'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
+ 'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
- 'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 0,
+ 'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 0,
  'HAVE_GETHOSTBYNAME_R': 1,
@@ -158,6 +210,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
+ 'HAVE_GETRANDOM': 0,
+ 'HAVE_GETRANDOM_SYSCALL': 0,
  'HAVE_GETRESGID': 0,
  'HAVE_GETRESUID': 0,
  'HAVE_GETSID': 1,
@@ -165,10 +219,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETSPNAM': 0,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
+ 'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
+ 'HAVE_HTOLE64': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 1,
+ 'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
@@ -176,6 +233,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
+ 'HAVE_IPA_PURE_CONST_BUG': 0,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
@@ -191,46 +249,72 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
+ 'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
+ 'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_CAN_BCM_H': 0,
+ 'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
+ 'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
+ 'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
+ 'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
+ 'HAVE_MBRTOWC': 1,
  'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMRCHR': 1,
+ 'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
+ 'HAVE_MKFIFOAT': 1,
  'HAVE_MKNOD': 1,
+ 'HAVE_MKNODAT': 1,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 1,
  'HAVE_NCURSES_H': 0,
  'HAVE_NDIR_H': 0,
  'HAVE_NETPACKET_PACKET_H': 0,
+ 'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE2': 1,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
+ 'HAVE_POSIX_FADVISE': 1,
+ 'HAVE_POSIX_FALLOCATE': 1,
+ 'HAVE_PREAD': 1,
+ 'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
+ 'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
+ 'HAVE_PWRITE': 1,
  'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
+ 'HAVE_READLINKAT': 1,
+ 'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RENAMEAT': 1,
+ 'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
@@ -239,19 +323,28 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_ROUND': 1,
+ 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
+ 'HAVE_SCHED_H': 1,
+ 'HAVE_SCHED_RR_GET_INTERVAL': 1,
+ 'HAVE_SCHED_SETAFFINITY': 0,
+ 'HAVE_SCHED_SETPARAM': 1,
+ 'HAVE_SCHED_SETSCHEDULER': 1,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
  'HAVE_SEM_UNLINK': 1,
+ 'HAVE_SENDFILE': 0,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
+ 'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
+ 'HAVE_SETPRIORITY': 1,
  'HAVE_SETREGID': 1,
  'HAVE_SETRESGID': 0,
  'HAVE_SETRESUID': 0,
@@ -261,9 +354,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
+ 'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
+ 'HAVE_SIGPENDING': 1,
  'HAVE_SIGRELSE': 1,
+ 'HAVE_SIGTIMEDWAIT': 1,
+ 'HAVE_SIGWAIT': 1,
+ 'HAVE_SIGWAITINFO': 1,
  'HAVE_SNPRINTF': 1,
  'HAVE_SOCKADDR_SA_LEN': 1,
  'HAVE_SOCKADDR_STORAGE': 1,
@@ -276,10 +374,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
+ 'HAVE_STD_ATOMIC': 0,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
@@ -290,14 +390,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
  'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
+ 'HAVE_SYMLINKAT': 1,
+ 'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
+ 'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
+ 'HAVE_SYS_ENDIAN_H': 1,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
+ 'HAVE_SYS_IOCTL_H': 1,
+ 'HAVE_SYS_KERN_CONTROL_H': 0,
  'HAVE_SYS_LOADAVG_H': 0,
  'HAVE_SYS_LOCK_H': 1,
  'HAVE_SYS_MKDEV_H': 0,
@@ -307,23 +413,27 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
+ 'HAVE_SYS_SENDFILE_H': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
+ 'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYS_DOMAIN_H': 0,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
+ 'HAVE_SYS_UIO_H': 1,
  'HAVE_SYS_UN_H': 1,
  'HAVE_SYS_UTSNAME_H': 1,
  'HAVE_SYS_WAIT_H': 1,
+ 'HAVE_SYS_XATTR_H': 1,
  'HAVE_TCGETPGRP': 1,
  'HAVE_TCSETPGRP': 1,
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
  'HAVE_TGAMMA': 1,
- 'HAVE_THREAD_H': 0,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -338,85 +448,116 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
+ 'HAVE_UNLINKAT': 1,
  'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 1,
+ 'HAVE_UTIMENSAT': 1,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
+ 'HAVE_WAITID': 1,
  'HAVE_WAITPID': 1,
  'HAVE_WCHAR_H': 1,
  'HAVE_WCSCOLL': 1,
+ 'HAVE_WCSFTIME': 1,
+ 'HAVE_WCSXFRM': 1,
+ 'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
+ 'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
  'HOST_GNU_TYPE': 'arm--netbsdelf-eabi',
- 'HURD_C_THREADS': 0,
- 'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include /usr/pkg/include/python2.7 /usr/pkg/include/python2.7',
+ 'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
+                   '/usr/pkg/include/python3.5 /usr/pkg/include/python3.5',
  'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python2.7',
+ 'INCLUDEPY': '/usr/pkg/include/python3.5',
  'INSTALL': '/usr/bin/install -c -o root -g wheel',
  'INSTALL_DATA': '/usr/bin/install -c -o root -g wheel -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c -s -o root -g wheel -m 755',
  'INSTALL_SCRIPT': '/usr/bin/install -c -o root -g wheel -m 755',
  'INSTALL_SHARED': '/usr/bin/install -c -o root -g wheel -m 555',
- 'INSTSONAME': 'libpython2.7.so.1.0',
- 'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-L/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'INSTSONAME': 'libpython3.5.so.1.0',
+ 'IO_H': 'Modules/_io/_iomodule.h',
+ 'IO_OBJS': '\\',
+ 'LDCXXSHARED': 'c++ -pthread -shared',
+ 'LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib '
+            '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython2.7.so',
+ 'LDLIBRARY': 'libpython3.5.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -L/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11 -pthread -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'LDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib '
+             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib',
+ 'LDVERSION': '3.5',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python2.7',
+ 'LIBDEST': '/usr/pkg/lib/python3.5',
  'LIBDIR': '/usr/pkg/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBP': '/usr/pkg/lib/python2.7',
  'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python2.7/config',
- 'LIBRARY': 'libpython2.7.a',
+ 'LIBPL': '/usr/pkg/lib/python3.5/config-3.5',
+ 'LIBRARY': 'libpython3.5.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lutil',
- 'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
- 'LINKCC': 'gcc',
+ 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
+ 'LIBS': '-lintl -lpthread  -lutil',
+ 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
+ 'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
  'LN': '/bin/ln',
  'LOCALMODLIBS': '',
+ 'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'netbsd7',
  'MACHDEPPATH': ':plat-netbsd7',
  'MACHDEPS': 'plat-netbsd7',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python2.7',
- 'MACH_C_THREADS': 0,
+ 'MACHDESTLIB': '/usr/pkg/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc',
+ 'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/pkg/man',
- 'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/bin/mkdir -p',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/zipimport.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  '
+            'Modules/posixmodule.o  Modules/errnomodule.o  '
+            'Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  '
+            'Modules/_weakref.o  Modules/_functoolsmodule.o  '
+            'Modules/_operator.o  Modules/_collectionsmodule.o  '
+            'Modules/itertoolsmodule.o  Modules/atexitmodule.o  '
+            'Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  '
+            'Modules/_iomodule.o Modules/iobase.o Modules/fileio.o '
+            'Modules/bytesio.o Modules/bufferedio.o Modules/textio.o '
+            'Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  '
+            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
+ 'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OLDPATH': ':lib-old',
  'OPCODETARGETGEN': '\\',
  'OPCODETARGETGEN_FILES': '\\',
  'OPCODETARGETS_H': '\\',
- 'OPT': '-DNDEBUG -O2  -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include',
+ 'OPCODE_H': './Include/opcode.h',
+ 'OPCODE_H_DIR': './Include',
+ 'OPCODE_H_GEN': '@echo python: not-found! cannot run '
+                 'Tools/scripts/generate_opcode_h.py  '
+                 './Tools/scripts/generate_opcode_h.py ./Lib/opcode.py '
+                 './Include/opcode.h',
+ 'OPCODE_H_SCRIPT': './Tools/scripts/generate_opcode_h.py',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -425,7 +566,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
@@ -434,43 +575,55 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-netbsd7',
- 'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
- 'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
+ 'PY3LIBRARY': 'libpython3.so',
  'PYLONG_BITS_IN_DIGIT': 0,
  'PYTHON': 'python',
  'PYTHONFRAMEWORK': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-netbsd7:lib-tk:lib-old',
+ 'PYTHONPATH': ':plat-netbsd7',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include -DNDEBUG -O2  -DHAVE_DB_185_H -pthread -I/usr/include -I/usr/pkg/include -I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
+              '-O2 -I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include',
+ 'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include -O2 '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -Werror=declaration-after-statement -I. '
+                   '-IInclude -I./Include -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/usr/include -I/usr/pkg/include '
+                '-I/usr/include -I/usr/pkg/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 'unsigned short',
+ 'PY_LDFLAGS': '-L. -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
+               '-Wl,-R/usr/pkg/lib',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 2,
- 'Py_USING_UNICODE': 1,
- 'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
+ 'Py_HASH_ALGORITHM': 0,
+ 'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
+ 'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lutil',
- 'SHLIB_EXT': '".so"',
+ 'SHLIBS': '-lintl -lpthread  -lutil',
+ 'SHLIB_SUFFIX': '.so',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -491,53 +644,52 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
- 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
+ 'SOABI': 'cpython-35',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
- 'STRINGLIB_HEADERS': '\\',
+ 'STRIPFLAG': '-s',
  'SUBDIRS': '',
- 'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SVNVERSION': 'echo Unversioned directory',
+ 'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
- 'TESTOPTS': '-l',
+ 'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1 '
+               './python',
  'TESTPYTHONOPTS': '',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1 '
+               './python ./Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
+ 'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
- 'TKPATH': ':lib-tk',
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
+ 'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
- 'USE_TOOLBOX_OBJECT_GLUE': 0,
+ 'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '2.7',
+ 'VERSION': '3.5',
  'WANT_SIGFPE_HANDLER': 0,
- 'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
- 'WITH_PYMALLOC': 1,
+ 'WITH_PYMALLOC': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11',
- 'abs_srcdir': '/mnt/earm/pkgsrc/lang/python27/work.earm/Python-2.7.11',
- 'build': 'arm--netbsdelf-eabi',
+ 'abs_builddir': '/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1',
+ 'abs_srcdir': '/mnt/earm/pkgsrc/lang/python35/work.earm/Python-3.5.1',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
- 'host': 'arm--netbsdelf-eabi',
  'prefix': '/usr/pkg',
  'srcdir': '.'}
